PosixTimer

Struct PosixTimer 

pub struct PosixTimer {
    pub id: u64,
    shared: Arc<PosixTimerShared>,
    handler: Arc<PosixTimerHandler>,
}
Public representation of a POSIX timer stored in the Linux ABI state.

Fields

id: u64shared: Arc<PosixTimerShared>handler: Arc<PosixTimerHandler>

Implementations

Source

impl PosixTimer

pub fn new( id: u64, clock_id: i32, sigev_notify: i32, sigev_signo: i32, sigev_value: u64, owner_task_id: usize, signal_state: Arc<Mutex<SignalState>>, ) -> Self

pub fn schedule(&self, first_ns: u64, interval_ns: u64)

Schedule (or reschedule) this timer with the specified first expiration and interval.

A zero first_ns disarms the timer.

pub fn cancel(&self)

Cancel any outstanding kernel timer and mark this POSIX timer inactive.

pub fn snapshot(&self) -> (u64, u64)

Snapshot the remaining time (in ns) and current interval (in ns).

pub fn state(&self) -> MutexGuard<'_, PosixTimerState>